@@ -4,10 +4,10 @@ use strict;
 use warnings;
 
 our ( $VERSION );
-$VERSION = '0.04_01';
+$VERSION = '0.01';
 
 use base 'IO::SWF';
-use IO::SWF::Bit;
+use IO::Bit;
 use IO::SWF::Tag::Shape;
 use IO::SWF::Tag::Action;
 use IO::SWF::Tag::Sprite;
@@ -30,10 +30,10 @@ IO::SWF::Editor - Parse and edit SWF binary by Perl.
 
 =head1 VERSION
 
-This document references version 0.04_01 of IO::SWF::Editor, released
-to CPAN on Aug 10, 2011.
+This document references version 0.01 of IO::SWF::Editor, released
+to CPAN on July 19, 2011.
 
-=head1 DESCRIPTION
+head1 DESCRIPTION
 
 IO::SWF::Editor provides to parse and edit SWF binary.
 
@@ -92,7 +92,7 @@ sub rebuild {
 sub setCharacterId {
     my $self = shift;
     foreach my $tag (@{$self->_tags}) {
-        my $content_reader = IO::SWF::Bit->new();
+        my $content_reader = IO::Bit->new();
         $content_reader->input($tag->content);
         if (
             $tag->code == 6  || # DefineBits
@@ -117,7 +117,7 @@ sub setCharacterId {
 sub setReferenceId {
     my $self = shift;
     foreach my $tag (@{$self->_tags}) {
-        my $content_reader = IO::SWF::Bit->new();
+        my $content_reader = IO::Bit->new();
         $content_reader->input($tag->content);
         if ($tag->code == 4 || # 4:  // PlaceObject
             $tag->code == 5    # 5:  // RemoveObject
