@@ -5,7 +5,7 @@ use warnings;
 
 use base 'IO::SWF::Tag::Base';
 
-use IO::SWF::Bit;
+use IO::Bit;
 use IO::SWF::Type::RECT;
 use IO::SWF::Type::FILLSTYLEARRAY;
 use IO::SWF::Type::LINESTYLEARRAY;
@@ -30,27 +30,27 @@ sub parseContent {
     my ($self, $tagCode, $content, $opts_href) = @_;
 
     my $isMorph = ($tagCode == 46 || $tagCode == 84) ? 1 : 0;
-    my $reader = IO::SWF::Bit->new();
+    my $reader = IO::Bit->new();
     $reader->input($content);
     $self->_shapeId($reader->getUI16LE());
 
     my %opts = ('tagCode' => $tagCode, 'isMorph' => $isMorph);
 
     if (!$isMorph) {
-        # style
+        # 描画スタイル
         $self->_shapeBounds(IO::SWF::Type::RECT::parse($reader));
         $self->_fillStyles(IO::SWF::Type::FILLSTYLEARRAY::parse($reader, \%opts));
         $self->_lineStyles(IO::SWF::Type::LINESTYLEARRAY::parse($reader, \%opts));
-        # shape
+        # 描画枠
         $self->_shapeRecords(IO::SWF::Type::SHAPE::parse($reader, \%opts));
     } else {
         $self->_startBounds(IO::SWF::Type::RECT::parse($reader));
         $self->_endBounds(IO::SWF::Type::RECT::parse($reader));
         $self->_offset($reader->getUI32LE());
-        # style
+        # 描画スタイル
         $self->_morphFillStyles(IO::SWF::Type::FILLSTYLEARRAY::parse($reader, \%opts));
         $self->_morphLineStyles(IO::SWF::Type::LINESTYLEARRAY::parse($reader, \%opts));
-        # shape
+        # 描画枠
         $self->_startEdge(IO::SWF::Type::SHAPE::parse($reader, \%opts));
         $self->_endEdge(IO::SWF::Type::SHAPE::parse($reader, \%opts));
     }
@@ -94,7 +94,7 @@ sub buildContent {
     my %opts = ref($opts_href) ? %{$opts_href} : ();
 
     my $isMorph = ($tagCode == 46 || $tagCode == 84) ? 1 : 0;
-    my $writer = IO::SWF::Bit->new();
+    my $writer = IO::Bit->new();
     if (!exists($opts{'noShapeId'})) {
         $writer->putUI16LE($self->_shapeId);
     }
@@ -102,20 +102,20 @@ sub buildContent {
 
     if (!$isMorph) {
         IO::SWF::Type::RECT::build($writer, $self->_shapeBounds);
-        # style
+        # 描画スタイル
         IO::SWF::Type::FILLSTYLEARRAY::build($writer, $self->_fillStyles, \%opts);
         IO::SWF::Type::LINESTYLEARRAY::build($writer, $self->_lineStyles, \%opts);
-        # shape
+        # 描画枠
         $opts{'fillStyleCount'} = scalar(@{$self->_fillStyles});
         $opts{'lineStyleCount'} = scalar(@{$self->_lineStyles});
         IO::SWF::Type::SHAPE::build($writer, $self->_shapeRecords, \%opts);
     } else {
         IO::SWF::Type::RECT::build($writer, $self->_startBounds);
         IO::SWF::Type::RECT::build($writer, $self->_endBounds);
-        # style
+        # 描画スタイル
         IO::SWF::Type::FILLSTYLEARRAY::build($writer, $self->_morphFillStyles, \%opts);
         IO::SWF::Type::LINESTYLEARRAY::build($writer, $self->_morphLineStyles, \%opts);
-        # shape
+        # 描画枠
         $opts{'fillStyleCount'} = scalar(@{$self->_morphFillStyles});
         $opts{'lineStyleCount'} = scalar(@{$self->_morphLineStyles});
         IO::SWF::Type::SHAPE::build($writer, $self->_startEdge, \%opts);
@@ -168,15 +168,16 @@ sub deformeShapeRecordUnit_1 {
         $shapeRecord = @{$self->_shapeRecords}[$i];
         my ($diff_x, $diff_y, $distance_2, $distance_2_control, $distance_2_anchor);
         if ($shapeRecord->{'StraightFlag'} == 0) {
-            # process for curve
+            # 曲線に対する処理
             $diff_x = $shapeRecord->{'ControlX'} - $currentDrawingPositionX;
             $diff_y = $shapeRecord->{'ControlY'} - $currentDrawingPositionY;
             $distance_2_control = $diff_x * $diff_x + $diff_y * $diff_y;
             $diff_x = $shapeRecord->{'AnchorX'} - $currentDrawingPositionX;
             $diff_y = $shapeRecord->{'AnchorY'} - $currentDrawingPositionY;
             $distance_2_anchor = $diff_x * $diff_x + $diff_y * $diff_y;
+#                if (max($distance_2_control, $distance_2_anchor) > $threshold_2) {
             if (($distance_2_control +  $distance_2_anchor) > $threshold_2) {
-                # nothing
+                # 何もしない
                 $prevIndex = $i;
                 $prevDrawingPositionX = $currentDrawingPositionX;
                 $prevDrawingPositionY = $currentDrawingPositionY;
@@ -184,7 +185,7 @@ sub deformeShapeRecordUnit_1 {
                 $currentDrawingPositionY = $shapeRecord->{'AnchorY'};
                 next; # skip
             }
-            # convert to straight
+            # 直線に変換する
             $shapeRecord->{'StraightFlag'} = 1; # to Straight
             $shapeRecord->{'X'} = $shapeRecord->{'AnchorX'};
             $shapeRecord->{'Y'} = $shapeRecord->{'AnchorY'};
@@ -194,7 +195,7 @@ sub deformeShapeRecordUnit_1 {
             delete $shapeRecord->{'AnchorY'};
         }
         if (!$prevIndex) {
-            # nothing
+            # 何もしない
             $prevIndex = $i;
             $prevDrawingPositionX = $currentDrawingPositionX;
             $prevDrawingPositionY = $currentDrawingPositionY;
@@ -206,7 +207,7 @@ sub deformeShapeRecordUnit_1 {
         $diff_y = $shapeRecord->{'Y'} - $prevDrawingPositionY;
         $distance_2 = $diff_x * $diff_x + $diff_y * $diff_y;
         if ($distance_2 > $threshold_2) {
-            # nothing
+            # 何もしない
             $prevIndex = $i;
             $prevDrawingPositionX = $currentDrawingPositionX;
             $prevDrawingPositionY = $currentDrawingPositionY;
@@ -214,7 +215,7 @@ sub deformeShapeRecordUnit_1 {
             $currentDrawingPositionY = $shapeRecord->{'Y'};
             next; # skip
         }
-        # joint to previous shape
+        # 前の直線にくっつける。
         my $prevShapeRecord = @{$self->_shapeRecords}[$prevIndex];
         $prevShapeRecord->{'X'} = $shapeRecord->{'X'};
         $prevShapeRecord->{'Y'} = $shapeRecord->{'Y'};
@@ -239,7 +240,7 @@ sub deformeShapeRecordUnit_2_curve {
     for (my $i = $startIndex + 1 ;$i <= $endIndex; $i++) {
         $shapeRecord = @{$self->_shapeRecords}[$i];
         if ($shapeRecord->{'StraightFlag'} == 0) {
-            # process for curve
+        # 曲線に対する処理
             my $diff_x = $shapeRecord->{'ControlX'} - $currentDrawingPositionX;
             my $diff_y = $shapeRecord->{'ControlY'} - $currentDrawingPositionY;
             my $distance_2_control = $diff_x * $diff_x + $diff_y * $diff_y;
@@ -247,12 +248,12 @@ sub deformeShapeRecordUnit_2_curve {
             $diff_y = $shapeRecord->{'AnchorY'} - $currentDrawingPositionY;
             my $distance_2_anchor = $diff_x * $diff_x + $diff_y * $diff_y;
             if (($distance_2_control +  $distance_2_anchor) > $threshold_2) {
-                # nothing
+                # 何もしない
                 $currentDrawingPositionX = $shapeRecord->{'AnchorX'};
                 $currentDrawingPositionY = $shapeRecord->{'AnchorY'};
                 next; # skip
             }
-            # convert to straight
+            # 直線に変換する
             $shapeRecord->{'StraightFlag'} = 1; # to Straight
             $shapeRecord->{'X'} = $shapeRecord->{'AnchorX'};
             $shapeRecord->{'Y'} = $shapeRecord->{'AnchorY'};
@@ -306,14 +307,16 @@ sub deformeShapeRecordUnit_2_line {
     my $deforme_number = 0;
     foreach my $i (@distance_list_short) {
         if ($distance_table_all[$i] > $threshold_2) {
-            next;
+            next; # 一定距離以上の線分は処理しない
         }
         if (!defined ($distance_list_all[$i-1]) && !defined ($distance_list_all[$i+1])) {
+            # 隣の線分が吸収され済みor曲線の場合は処理しない
 
         }
         my $index_to_merge;
         if (!defined ($distance_list_all[$i-1])) {
             if (!defined ($distance_list_all[$i+1])) {
+                # 隣の線分が吸収されている場合は処理しない
                 next;           
             } else {
                 $index_to_merge = $i+1;
@@ -322,9 +325,10 @@ sub deformeShapeRecordUnit_2_line {
             if (!defined ($distance_list_all[$i+1])) {
                 $index_to_merge = $i-1;
             } else {
-                $index_to_merge = $i-1; # XXX
+                $index_to_merge = $i-1; # XXX 後で選択する処理を入れる
             }
         }
+        # line merge 処理
         $shapeRecord = @{$self->_shapeRecords}[$i];
         my $shapeRecord_toMerge = @{$self->_shapeRecords}[$index_to_merge];
         if ($i > $index_to_merge) {
