@@ -5,7 +5,7 @@ use warnings;
 
 use base 'IO::SWF::Type';
 
-use IO::SWF::Bit;
+use IO::Bit;
 use IO::SWF::Type::LINESTYLE;
 
 sub parse {
@@ -17,6 +17,7 @@ sub parse {
     # LineStyle
     my $lineStyleCount = $reader->getUI8();
     if (($tagCode > 2) && ($lineStyleCount == 0xff)) {
+        # DefineShape2 以降は 0xffff サイズまで扱える
         $lineStyleCount = $reader->getUI16LE();
     }
     for (my $i = 0 ; $i < $lineStyleCount ; $i++) {
