@@ -6,7 +6,7 @@ use warnings;
 use base 'IO::SWF::Type';
 
 use List::Util;
-use IO::SWF::Bit;
+use IO::Bit;
 use IO::SWF::Type::FILLSTYLEARRAY;
 use IO::SWF::Type::LINESTYLEARRAY;
 
@@ -17,6 +17,7 @@ sub parse {
     my @shapeRecords = ();
 
     $reader->byteAlign();
+    # 描画スタイルを参照するインデックスのビット幅
     my $numFillBits = $reader->getUIBits(4);
     my $numLineBits = $reader->getUIBits(4);
 
